@@ -28,16 +28,13 @@
 #include <CalendarSupport/CellItem>
 
 #include <Akonadi/Calendar/ETMCalendar>
-#include <Item>
-
-#include <KDateTime>
+#include <AkonadiCore/Item>
 
+#include <QDateTime>
 #include <QWidget>
 #include <QPointer>
 
-namespace EventViews
-{
-
+namespace EventViews {
 class AgendaItem;
 class EventView;
 
@@ -84,45 +81,39 @@ public:
     typedef QPointer<AgendaItem> QPtr;
     typedef QList<QPtr> List;
 
-    AgendaItem(EventView *eventView,
-               const MultiViewCalendar::Ptr &calendar,
-               const KCalCore::Incidence::Ptr &incidence,
-               int itemPos,
-               int itemCount,
-               const KDateTime &qd,
-               bool isSelected,
+    AgendaItem(EventView *eventView, const MultiViewCalendar::Ptr &calendar, const KCalCore::Incidence::Ptr &incidence, int itemPos, int itemCount, const QDateTime &qd, bool isSelected,
                QWidget *parent);
-    ~AgendaItem();
+    ~AgendaItem() override;
 
-    int cellXLeft() const
+    Q_REQUIRED_RESULT int cellXLeft() const
     {
         return mCellXLeft;
     }
 
-    int cellXRight() const
+    Q_REQUIRED_RESULT int cellXRight() const
     {
         return mCellXRight;
     }
 
-    int cellYTop() const
+    Q_REQUIRED_RESULT int cellYTop() const
     {
         return mCellYTop;
     }
 
-    int cellYBottom() const
+    Q_REQUIRED_RESULT int cellYBottom() const
     {
         return mCellYBottom;
     }
 
-    int cellHeight() const;
-    int cellWidth() const;
+    Q_REQUIRED_RESULT int cellHeight() const;
+    Q_REQUIRED_RESULT int cellWidth() const;
 
-    int itemPos() const
+    Q_REQUIRED_RESULT int itemPos() const
     {
         return mItemPos;
     }
 
-    int itemCount() const
+    Q_REQUIRED_RESULT int itemCount() const
     {
         return mItemCount;
     }
@@ -159,7 +150,7 @@ public:
     void expandLeft(int dx);
     void expandRight(int dx);
 
-    bool isMultiItem() const;
+    Q_REQUIRED_RESULT bool isMultiItem() const;
 
     AgendaItem::QPtr prevMoveItem() const
     {
@@ -176,8 +167,7 @@ public:
         return mStartMoveInfo;
     }
 
-    void setMultiItem(const AgendaItem::QPtr &first, const AgendaItem::QPtr &prev,
-                      const AgendaItem::QPtr &next, const AgendaItem::QPtr &last);
+    void setMultiItem(const AgendaItem::QPtr &first, const AgendaItem::QPtr &prev, const AgendaItem::QPtr &next, const AgendaItem::QPtr &last);
 
     AgendaItem::QPtr prependMoveItem(const AgendaItem::QPtr &);
 
@@ -205,7 +195,7 @@ public:
         return (mMultiItemInfo) ? (mMultiItemInfo->mLastMultiItem) : nullptr;
     }
 
-    bool dissociateFromMultiItem();
+    Q_REQUIRED_RESULT bool dissociateFromMultiItem();
 
     void setIncidence(const KCalCore::Incidence::Ptr &incidence);
 
@@ -214,22 +204,22 @@ public:
         return mIncidence;
     }
 
-    KDateTime occurrenceDateTime() const
+    Q_REQUIRED_RESULT QDateTime occurrenceDateTime() const
     {
         return mOccurrenceDateTime;
     }
 
-    QDate occurrenceDate() const;
+    Q_REQUIRED_RESULT QDate occurrenceDate() const;
 
     // /** Update the date of this item's occurrence (not in the event) */
-    void setOccurrenceDateTime(const KDateTime &qd);
+    void setOccurrenceDateTime(const QDateTime &qd);
 
     void setText(const QString &text)
     {
         mLabelText = text;
     }
 
-    QString text()
+    Q_REQUIRED_RESULT QString text() const
     {
         return mLabelText;
     }
@@ -248,7 +238,7 @@ public:
         mResourceColor = color;
     }
 
-    QColor resourceColor()
+    Q_REQUIRED_RESULT QColor resourceColor() const
     {
         return mResourceColor;
     }
@@ -277,7 +267,7 @@ protected:
     void endMovePrivate();
 
     // Variables to remember start position
-    MultiItemInfo *mStartMoveInfo;
+    MultiItemInfo *mStartMoveInfo = nullptr;
     //Color of the resource
     QColor mResourceColor;
 
@@ -287,17 +277,15 @@ private:
     // paint all visible icons
     void paintIcons(QPainter *p, int &x, int y, int ft);
 
-    void drawRoundedRect(QPainter *p, const QRect &rect,
-                         bool selected, const QColor &bgcolor,
-                         bool frame, int ft, bool roundTop, bool roundBottom);
+    void drawRoundedRect(QPainter *p, const QRect &rect, bool selected, const QColor &bgcolor, bool frame, int ft, bool roundTop, bool roundBottom);
 
     int mCellXLeft, mCellXRight;
     int mCellYTop, mCellYBottom;
 
-    EventView *mEventView;
+    EventView *mEventView = nullptr;
     MultiViewCalendar::Ptr mCalendar;
     KCalCore::Incidence::Ptr mIncidence;
-    KDateTime mOccurrenceDateTime;
+    QDateTime mOccurrenceDateTime;
     bool mValid;
     bool mCloned;
     QString mLabelText;
@@ -312,7 +300,7 @@ private:
     int mItemCount;
 
     // Multi item pointers
-    MultiItemInfo *mMultiItemInfo;
+    MultiItemInfo *mMultiItemInfo = nullptr;
 
     QList<AgendaItem::QPtr> mConflictItems;
 
@@ -327,7 +315,6 @@ private:
     static QPixmap *todoPxmp;
     static QPixmap *completedPxmp;
 };
-
 }
 
 #endif
